surface_dynamics: dynamics on surfaces (measured foliations, interval exchange transformation, Teichmüller flow, etc)
======================================================================================================================

Description
-----------

Dynamics on surfaces.

License
-------

GPLv2+

Upstream Contact
----------------

https://gitlab.com/videlec/surface_dynamics
https://pypi.org/project/surface-dynamics/
